Documentation
¶
Overview ¶
Package flat provides a flat view of an arbitrary nested structs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrUnexpectedType is returned when flatten sees an unsupported type. ErrUnexpectedType = errors.New("Unexpected type, expecting a pointer to struct") )
Functions ¶
This section is empty.
Types ¶
type Field ¶
type Field interface {
Name() string
Tag(key string) (string, bool)
Meta() map[string]string
String() string
Set(string) error
IsZero() bool
}
Field describe an interface to our flat structs fields.
Click to show internal directories.
Click to hide internal directories.